utils — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# utils

Helper functions for the view subpackage

`camelot.view.utils.` `default_language`(*args)

  takes arguments, to be able to use this function as a default field attribute

`camelot.view.utils.` `local_date_format`()

  Get the local data format and cache it for reuse

`camelot.view.utils.` `local_datetime_format`()

  Get the local datatime format and cache it for reuse

`camelot.view.utils.` `local_time_format`()

  Get the local time format and cache it for reuse

`camelot.view.utils.` `text_from_richtext`(unstripped_text)

  funciton that returns a list of lines with escaped data, to be used in templates for example :arg unstripped_text: string :return: list of strings

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus